@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2011-2016 Canonical
+ * Copyright (C) 2011-2017 Canonical
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -322,7 +322,6 @@ static void handle_sigwinch(int sig)
 {
 	(void)sig;
 
-	df.df_winsize(true);
 	resized = true;
 }
 
@@ -1749,7 +1748,7 @@ static void get_cpustats(
 		fnptr = filename;
 		fnptr += putstr(fnptr, 6, "/proc/");
 		fnptr += putstr(fnptr, PATH_MAX - 6, entry->d_name);
-		fnptr += putstr(fnptr, 5, "/stat");
+		putstr(fnptr, 5, "/stat");
 		if ((fd = open(filename, O_RDONLY)) < 0)
 			continue;
 
@@ -1856,7 +1855,7 @@ static double cpu_freq_average(uint32_t max_cpus)
 		fnptr = filename;
 		fnptr += putstr(fnptr, 28, "/sys/devices/system/cpu/cpu");
 		fnptr += putuint(fnptr, i);
-		fnptr += putstr(fnptr, 25, "/cpufreq/scaling_cur_freq");
+		putstr(fnptr, 25, "/cpufreq/scaling_cur_freq");
 
 		if (LIKELY((fd = open(filename, O_RDONLY)) > -1)) {
 			char buffer[64];
@@ -1899,7 +1898,7 @@ static char *cpu_freq_format(double freq)
 
 	ptr += putdouble_decpl(buffer, freq / scale, 2);
 	*(ptr++) = ' ';
-	ptr += putstr(ptr, 3, suffix);
+	putstr(ptr, 3, suffix);
 
 	return buffer;
 }
@@ -2252,9 +2251,10 @@ int main(int argc, char **argv)
 retry:
 		if (UNLIKELY(select(0, NULL, NULL, NULL, &tv) < 0)) {
 			if (errno == EINTR) {
-				if (!resized)
+				if (!resized) {
 					stop_cpustat = true;
-				else {
+					df.df_winsize(true);
+				} else {
 					redo = true;
 					if (timeval_to_double(&tv) > 0.0)
 						goto retry;
